Documentation
¶
Index ¶
- type KerbruteSession
- func (k KerbruteSession) DumpASRepHash(asrep messages.ASRep)
- func (k KerbruteSession) HandleKerbError(err error) (bool, string)
- func (k KerbruteSession) TestLogin(username, password string) (bool, error)
- func (k KerbruteSession) TestLoginError(err error) (bool, error)
- func (k KerbruteSession) TestUsername(username string) (bool, string, error)
- type KerbruteSessionOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KerbruteSession ¶
type KerbruteSession struct {
Domain string
Realm string
Kdcs map[int]string
ConfigString string
Config *kconfig.Config
Verbose bool
SafeMode bool
NTHash bool
SocksAddr string
EncryptionType string
HashFile *os.File
Logger *util.Logger
ProgressBar *progressbar.ProgressBar
}
func NewKerbruteSession ¶
func NewKerbruteSession(options KerbruteSessionOptions) (k KerbruteSession, err error)
func (KerbruteSession) DumpASRepHash ¶
func (k KerbruteSession) DumpASRepHash(asrep messages.ASRep)
func (KerbruteSession) HandleKerbError ¶
func (k KerbruteSession) HandleKerbError(err error) (bool, string)
func (KerbruteSession) TestLogin ¶
func (k KerbruteSession) TestLogin(username, password string) (bool, error)
func (KerbruteSession) TestLoginError ¶
func (k KerbruteSession) TestLoginError(err error) (bool, error)
TestLoginError returns true for certain KRB Errors that only happen when the password is correct The correct credentials we're passed, but the error prevented a successful TGT from being retrieved
func (KerbruteSession) TestUsername ¶
func (k KerbruteSession) TestUsername(username string) (bool, string, error)
Click to show internal directories.
Click to hide internal directories.